export default {
    "index": 21,
    "lineNumber": 1,
    "column": 22,
    "message": "Unexpected token await"
};